import CellValue from "./CellValue";
export type StringFilterOperator = "equals" | "notEquals" | "contains" | "notContains" | "startsWith" | "endsWith" | "isEmpty" | "isNotEmpty";
export type NumberFilterOperator = "equals" | "notEquals" | "greaterThan" | "lessThan" | "greaterThanOrEqual" | "lessThanOrEqual" | "between" | "notBetween" | "isEmpty" | "isNotEmpty";
export type BooleanFilterOperator = "equals" | "isEmpty" | "isNotEmpty";
export type DateFilterOperator = "equals" | "notEquals" | "before" | "after" | "between" | "notBetween" | "isEmpty" | "isNotEmpty";
export type EnumFilterOperator = "in" | "notIn" | "isEmpty" | "isNotEmpty";
export type FilterOperator = StringFilterOperator | NumberFilterOperator | BooleanFilterOperator | DateFilterOperator | EnumFilterOperator;
export interface FilterCondition {
    accessor: string;
    operator: FilterOperator;
    value?: CellValue;
    values?: CellValue[];
}
export interface TableFilterState {
    [accessor: string]: FilterCondition;
}
export declare const FILTER_OPERATOR_LABELS: Record<FilterOperator, string>;
export declare const getAvailableOperators: (columnType: "string" | "number" | "boolean" | "date" | "enum") => FilterOperator[];
export declare const requiresSingleValue: (operator: FilterOperator) => boolean;
export declare const requiresMultipleValues: (operator: FilterOperator) => boolean;
export declare const requiresNoValue: (operator: FilterOperator) => boolean;
